.. include:: ../README.rst
    :end-before: when included in index.rst

.. |plot| image:: images/plot_spec.png

How the documentation is structured
-----------------------------------

Documentation is split into four categories, also accessible from links in the
side-bar.

.. grid:: 4

    .. grid-item-card:: :material-regular:`person;4em`
        :link: tutorials
        :link-type: doc

        Tutorials

    .. grid-item-card:: :material-regular:`code;4em`
        :link: how-to
        :link-type: doc

        How-To

    .. grid-item-card:: :material-regular:`person;4em`
        :link: explanations
        :link-type: doc

        Explanations

    .. grid-item-card:: :material-regular:`code;4em`
        :link: reference
        :link-type: doc

        Reference


.. toctree::
    :hidden:

    tutorials
    how-to
    explanations
    reference
